==============
bisos.examples
==============

.. contents::
   :depth: 3
..

Overview
========

bisos.lcnt: Interactive Command Modules (ICM) and libraries to support
ByStar Libre Content (LCNT) capabilities for impressive (pdf
presentations), screenstudio (desktop recorder), etc.

Support
=======

| For support, criticism, comments and questions; please contact the
  author/maintainer
| `Mohsen Banan <http://mohsen.1.banan.byname.net>`__ at:
  http://mohsen.1.banan.byname.net/contact

Documentation
=============

Part of ByStar Digital Ecosystem http://www.by-star.net.

This module’s primary documentation is in
http://www.by-star.net/PLPC/180047

Installation
============

::

   sudo pip install bisos.lcnt

Usage
=====

::

   /usr/local/bin/beamerExternalExtensions.py
   /usr/local/bin/screenstudioWebClientIcm.py
